@@ -4,8 +4,6 @@ import numpy as np
 
 
 def solve_system():
-    permittivity_data = np.array([1, 1, 1, 1, 3, 3, 3, 3])
-    permeability_data = 1 + 0 * permittivity_data
 
     reflection_layer = Layer(er=1.0, ur=1.0)
     transmission_layer = Layer(er=9.0, ur=1.0)
@@ -17,7 +15,6 @@ def solve_system():
     phi = 1*deg
     pTEM = 1/np.sqrt(2)*complexArray([1,1j])
     source = Source(wavelength=wavelength, theta=theta, phi=phi, pTEM=pTEM, layer=reflection_layer)
-    lattice_vector = [1.0, 0, 0]
 
     crystal_thickness = 0.5
 
